@@ -5,16 +5,6 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from enum import Enum
 from typing import List, Optional
-
-
-try:
-    import torch
-    from transformers import AutoTokenizer, AutoModelForCausalLM, AutoModelForSeq2SeqLM, pipeline
-
-    TRANSFORMERS_AVAILABLE = True
-except ImportError:
-    TRANSFORMERS_AVAILABLE = False
-
 from google import genai
 from google.genai import types
 from groq import Groq
@@ -33,10 +23,10 @@ TRANSLATION_PROMPT = f"""
 **Professional Game Localization Task**
 
 **Task Directive:**
-Translate ONLY the single line of game dialogue specified below into natural-sounding, context-aware English. The translation must preserve the original tone and intent of the character.
+Translate ONLY the single line of game dialogue specified below into natural-sounding, context-aware {get_config().general.get_native_language_name()}. The translation must preserve the original tone and intent of the character.
 
 **Output Requirements:**
-- Provide only the single, best English translation.
+- Provide only the single, best {get_config().general.get_native_language_name()} translation.
 - Use expletives if they are natural for the context and enhance the translation's impact, but do not over-exaggerate.
 - Preserve or add HTML tags (e.g., `<i>`, `<b>`) if appropriate for emphasis.
 - Do not include notes, alternatives, explanations, or any other surrounding text. Absolutely nothing but the translated line.
@@ -47,7 +37,7 @@ Translate ONLY the single line of game dialogue specified below into natural-sou
 CONTEXT_PROMPT = textwrap.dedent(f"""
 
 **Task Directive:**
-Provide a very brief summary of the scene in English based on the provided Japanese dialogue and context. Focus on the characters' actions and the immediate situation being described.
+Provide a very brief summary of the scene in {get_config().general.get_native_language_name()} based on the provided Japanese dialogue and context. Focus on the characters' actions and the immediate situation being described.
 
 Current Sentence:
 """)
@@ -136,6 +126,13 @@ class AIManager(ABC):
 class LocalAIManager(AIManager):
     def __init__(self, model, logger: Optional[logging.Logger] = None):
         super().__init__(LocalAIConfig(model=model), logger)
+        try:
+            import torch
+            from transformers import AutoTokenizer, AutoModelForCausalLM, AutoModelForSeq2SeqLM, pipeline
+
+            self.transformers_available = True
+        except (ImportError, OSError):
+            self.transformers_available = False
         self.model_name = self.ai_config.model
         if MANUAL_MODEL_OVERRIDE:
             self.model_name = MANUAL_MODEL_OVERRIDE
@@ -147,7 +144,7 @@ class LocalAIManager(AIManager):
         self.is_encoder_decoder = False
         self.is_nllb = "nllb" in self.model_name.lower()
 
-        if not TRANSFORMERS_AVAILABLE:
+        if not self.transformers_available:
             self.logger.error("Local AI dependencies not found. Please run: pip install torch transformers sentencepiece")
             return
 
