@@ -139,9 +139,6 @@ def get_obs_websocket_config_values():
 
 async def connect_to_obs(retry=5):
     global client, obs_connection_manager, event_client, connecting
-    if not get_config().obs.enabled:
-        return
-
     if is_windows():
         get_obs_websocket_config_values()
 
@@ -181,9 +178,6 @@ async def connect_to_obs(retry=5):
 
 def connect_to_obs_sync(retry=2):
     global client, obs_connection_manager, event_client
-    if not get_config().obs.enabled or client:
-        return
-
     if is_windows():
         get_obs_websocket_config_values()
 
@@ -419,8 +413,8 @@ def get_screenshot_PIL(source_name=None, compression=75, img_format='png', width
 def update_current_game():
     gsm_state.current_game = get_current_scene()
 
-def get_current_game(sanitize=False):
-    if not gsm_state.current_game:
+def get_current_game(sanitize=False, update=True):
+    if not gsm_state.current_game or update:
         update_current_game()
 
     if sanitize:
@@ -468,6 +462,10 @@ if __name__ == '__main__':
     logging.basicConfig(level=logging.INFO)
     # main()
     connect_to_obs_sync()
+    
+    while True:
+        print(get_active_source())
+        time.sleep(3)
     # i = 100
     # for i in range(1, 100):
     #     print(f"Getting screenshot {i}")
