@@ -17,7 +17,7 @@ from PIL import Image
 from loguru import logger
 import requests
 
-from GameSentenceMiner.util.electron_config import get_ocr_language
+from GameSentenceMiner.util.electron_config import get_ocr_language, get_furigana_filter_sensitivity
 
 # from GameSentenceMiner.util.configuration import get_temporary_directory
 
@@ -275,6 +275,7 @@ class GoogleLens:
             logger.info('Google Lens ready')
 
     def __call__(self, img, furigana_filter_sensitivity=0, return_coords=False):
+        furigana_filter_sensitivity = get_furigana_filter_sensitivity()
         lang = get_ocr_language()
         img, is_path = input_to_pil_image(img)
         if lang != self.initial_lang:
@@ -344,7 +345,6 @@ class GoogleLens:
         text = response_dict['objects_response']['text']
         skipped = []
         previous_line = None
-        lines = []
         if 'text_layout' in text:
             for paragraph in text['text_layout']['paragraphs']:
                 if previous_line:
@@ -360,38 +360,21 @@ class GoogleLens:
                     if vertical_space > avg_height * 2:
                         res += 'BLANK_LINE'
                 for line in paragraph['lines']:
-                    # Build a list of word boxes for this line
-                    words_info = []
-                    for word in line['words']:
-                        word_info = {
-                            "word": word['plain_text'],
-                            "x1": int(word['geometry']['bounding_box']['center_x'] * img.width - (word['geometry']['bounding_box']['width'] * img.width) / 2),
-                            "y1": int(word['geometry']['bounding_box']['center_y'] * img.height - (word['geometry']['bounding_box']['height'] * img.height) / 2),
-                            "x2": int(word['geometry']['bounding_box']['center_x'] * img.width + (word['geometry']['bounding_box']['width'] * img.width) / 2),
-                            "y2": int(word['geometry']['bounding_box']['center_y'] * img.height + (word['geometry']['bounding_box']['height'] * img.height) / 2)
-                        }
-                        words_info.append(word_info)
-
-                    line_text = ''.join([w['word'] for w in words_info])
-                    line_box = {
-                        "sentence": line_text,
-                        "words": words_info
-                    }
-
-                    # Optionally apply furigana filter
                     if furigana_filter_sensitivity:
-                        line_width = line['geometry']['bounding_box']['width'] * img.width
-                        line_height = line['geometry']['bounding_box']['height'] * img.height
-                        if furigana_filter_sensitivity < line_width and furigana_filter_sensitivity < line_height and self.regex.search(line_text):
-                            for w in words_info:
-                                res += w['word']
-                        else:
-                            skipped.extend([w['word'] for w in words_info])
-                            continue
+                        for word in line['words']:
+                            if 'geometry' not in word:
+                                res += word['plain_text']
+                                continue
+                            word_width = word['geometry']['bounding_box']['width'] * img.width
+                            word_height = word['geometry']['bounding_box']['height'] * img.height
+                            if word_width > furigana_filter_sensitivity and word_height > furigana_filter_sensitivity:
+                                res += word['plain_text']
+                            else:
+                                skipped.extend([word['plain_text'] for word in line['words']])
+                                continue
                     else:
-                        for w in words_info:
-                            res += w['word']
-                    lines.append(line_box)
+                        for word in line['words']:
+                            res += word['plain_text']
                 previous_line = paragraph
                 res += '\n'
             # logger.info(
@@ -440,6 +423,9 @@ class GoogleLens:
         else:
             x = (True, res)
 
+        if skipped:
+            logger.info(f"Skipped {len(skipped)} chars due to furigana filter sensitivity: {furigana_filter_sensitivity}")
+
         # img.close()
         return x
 
@@ -910,6 +896,7 @@ class OneOCR:
 
     def __call__(self, img, furigana_filter_sensitivity=0, return_coords=False):
         lang = get_ocr_language()
+        furigana_filter_sensitivity = get_furigana_filter_sensitivity()
         if lang != self.initial_lang:
             self.initial_lang = lang
             self.regex = get_regex(lang)
@@ -1381,37 +1368,40 @@ class GroqOCR:
         return base64.b64encode(pil_image_to_bytes(img, png_compression=1)).decode('utf-8')
 
 # class QWENOCR:
-#     name = 'qwenvl'
+#     name = 'qwenv2'
 #     readable_name = 'Qwen2-VL'
 #     key = 'q'
 #     available = False
-#
+
 #     def __init__(self, config={}, lang='ja'):
 #         try:
 #             import torch
-#             from transformers import Qwen2VLForConditionalGeneration, AutoProcessor
-#             self.model = Qwen2VLForConditionalGeneration.from_pretrained(
+#             import transformers
+#             from transformers import AutoModelForImageTextToText, AutoProcessor
+#             self.model = AutoModelForImageTextToText.from_pretrained(
 #                 "Qwen/Qwen2-VL-2B-Instruct", torch_dtype="auto", device_map="auto"
 #             )
 #             self.processor = AutoProcessor.from_pretrained("Qwen/Qwen2-VL-2B-Instruct", use_fast=True)
 #             self.device = "cuda" if torch.cuda.is_available() else "cpu"
 #             print(self.device)
 #             self.available = True
-#             logger.info('Qwen2-VL ready')
+#             logger.info('Qwen2.5-VL ready')
 #         except Exception as e:
 #             logger.warning(f'Qwen2-VL not available: {e}')
-#
+
 #     def __call__(self, img, furigana_filter_sensitivity=0):
 #         if not self.available:
 #             return (False, 'Qwen2-VL is not available.')
 #         try:
-#             img = input_to_pil_image(img)
+#             img, is_path = input_to_pil_image(img)
+
+#             # img.show()
 #             conversation = [
 #                 {
 #                     "role": "user",
 #                     "content": [
 #                         {"type": "image"},
-#                         {"type": "text", "text": "Analyze the image. Extract text *only* from within dialogue boxes (speech bubbles or panels containing character dialogue). If Text appears to be vertical, read the text from top to bottom, right to left. From the extracted dialogue text, filter out any furigana. Ignore and do not include any text found outside of dialogue boxes, including character names, speaker labels, or sound effects. Return *only* the filtered dialogue text. If no text is found within dialogue boxes after applying filters, return nothing. Do not include any other output, formatting markers, or commentary."},
+#                         {"type": "text", "text": "Analyze the image. Extract text *only* from within dialogue boxes (speech bubbles or panels containing character dialogue). If Text appears to be vertical, read the text from top to bottom, right to left. From the extracted dialogue text, filter out any furigana (Small characters above the kanji). Ignore and do not include any text found outside of dialogue boxes, including character names, speaker labels, or sound effects. Return *only* the filtered dialogue text. If no text is found within dialogue boxes after applying filters, return nothing. Do not include any other output, formatting markers, or commentary."},
 #                     ],
 #                 }
 #             ]
@@ -1431,15 +1421,18 @@ class GroqOCR:
 #             return (True, output_text[0] if output_text else "")
 #         except Exception as e:
 #             return (False, f'Qwen2-VL inference failed: {e}')
+        
+#     def _preprocess(self, img):
+#         return base64.b64encode(pil_image_to_bytes(img, png_compression=6)).decode('utf-8')
 
 
 # qwenocr = QWENOCR()
-#
+
 # for i in range(10):
 #     start_time = time.time()
-#     res, text = qwenocr(Image.open('test_furigana.png'), furigana_filter_sensitivity=0)  # Example usage
+#     res, text = qwenocr(Image.open(r"C:\Users\Beangate\GSM\GameSentenceMiner\GameSentenceMiner\owocr\owocr\test_furigana.png"), furigana_filter_sensitivity=0)  # Example usage
 #     end_time = time.time()
-#
+
 #     print(f"Time taken: {end_time - start_time:.2f} seconds")
 #     print(text)
 # class LocalOCR:
