@@ -58,6 +58,39 @@ def is_linux():
 def is_windows():
     return platform == 'win32'
 
+class Locale(Enum):
+    English = 'en_us'
+    日本語 = 'ja_jp'
+    한국어 = 'ko_kr'
+    中文 = 'zh_cn'
+    Español = 'es_es'
+    Français = 'fr_fr'
+    Deutsch = 'de_de'
+    Italiano = 'it_it'
+    Русский = 'ru_ru'
+
+    @classmethod
+    def from_any(cls, value: str) -> 'Locale':
+        """
+        Lookup Locale by either enum name (e.g. 'English') or value (e.g. 'en_us').
+        Case-insensitive.
+        """
+        value_lower = value.lower()
+        for locale in cls:
+            if locale.name.lower() == value_lower or locale.value.lower() == value_lower:
+                return locale
+        raise KeyError(f"Locale '{value}' not found.")
+
+    def __getitem__(cls, item):
+        try:
+            return cls.from_any(item)
+        except KeyError:
+            raise
+        
+
+# Patch Enum's __getitem__ for this class
+Locale.__getitem__ = classmethod(Locale.__getitem__)
+
 
 class Language(Enum):
     JAPANESE = "ja"
@@ -79,6 +112,8 @@ class Language(Enum):
     DANISH = "da"
     NORWEGIAN = "no"
     
+    
+    
 
 AVAILABLE_LANGUAGES = [lang.value for lang in Language]
 AVAILABLE_LANGUAGES_DICT = {lang.value: lang for lang in Language}
@@ -331,16 +366,19 @@ class General:
 @dataclass
 class Paths:
     folder_to_watch: str = expanduser("~/Videos/GSM")
-    audio_destination: str = expanduser("~/Videos/GSM/Audio/")
-    screenshot_destination: str = expanduser("~/Videos/GSM/SS/")
+    output_folder: str = expanduser("~/Videos/GSM/Output")
+    copy_temp_files_to_output_folder: bool = False
+    open_output_folder_on_card_creation: bool = False
+    copy_trimmed_replay_to_output_folder: bool = False
     remove_video: bool = True
     remove_audio: bool = False
     remove_screenshot: bool = False
 
     def __post_init__(self):
-        self.folder_to_watch = os.path.normpath(self.folder_to_watch)
-        self.audio_destination = os.path.normpath(self.audio_destination)
-        self.screenshot_destination = os.path.normpath(self.screenshot_destination)
+        if self.folder_to_watch:
+            self.folder_to_watch = os.path.normpath(self.folder_to_watch)
+        if self.output_folder:
+            self.output_folder = os.path.normpath(self.output_folder)
 
 @dataclass_json
 @dataclass
@@ -434,7 +472,6 @@ class Audio:
 @dataclass_json
 @dataclass
 class OBS:
-    enabled: bool = True
     open_obs: bool = True
     close_obs: bool = True
     host: str = "127.0.0.1"
@@ -504,7 +541,7 @@ class Ai:
     enabled: bool = False
     anki_field: str = ''
     provider: str = AI_GEMINI
-    gemini_model: str = 'gemini-2.5-flash'
+    gemini_model: str = 'gemini-2.5-flash-lite'
     local_model: str = OFF
     groq_model: str = 'meta-llama/llama-4-scout-17b-16e-instruct'
     api_key: str = '' # Deprecated
@@ -523,6 +560,10 @@ class Ai:
             if self.provider == 'groq':
                 self.provider = AI_GROQ
                 
+        # Change Legacy Model Name
+        if self.gemini_model == 'gemini-2.5-flash-lite-preview-06-17':
+            self.gemini_model = 'gemini-2.5-flash-lite'
+                
                 
 # Experimental Features section, will change often
 @dataclass_json
@@ -570,10 +611,6 @@ class ProfileConfig:
             config_data = toml.load(f)
 
         self.paths.folder_to_watch = expanduser(config_data['paths'].get('folder_to_watch', self.paths.folder_to_watch))
-        self.paths.audio_destination = expanduser(
-            config_data['paths'].get('audio_destination', self.paths.audio_destination))
-        self.paths.screenshot_destination = expanduser(config_data['paths'].get('screenshot_destination',
-                                                                                self.paths.screenshot_destination))
 
         self.anki.url = config_data['anki'].get('url', self.anki.url)
         self.anki.sentence_field = config_data['anki'].get('sentence_field', self.anki.sentence_field)
@@ -611,7 +648,6 @@ class ProfileConfig:
                                                                      self.vad.do_vad_postprocessing)
         self.vad.trim_beginning = config_data['audio'].get('vosk_trim_beginning', self.vad.trim_beginning)
 
-        self.obs.enabled = config_data['obs'].get('enabled', self.obs.enabled)
         self.obs.host = config_data['obs'].get('host', self.obs.host)
         self.obs.port = config_data['obs'].get('port', self.obs.port)
         self.obs.password = config_data['obs'].get('password', self.obs.password)
@@ -650,11 +686,19 @@ class Config:
     configs: Dict[str, ProfileConfig] = field(default_factory=dict)
     current_profile: str = DEFAULT_CONFIG
     switch_to_default_if_not_found: bool = True
+    locale: str = Locale.English.value
 
     @classmethod
     def new(cls):
         instance = cls(configs={DEFAULT_CONFIG: ProfileConfig()}, current_profile=DEFAULT_CONFIG)
         return instance
+    
+    def get_locale(self) -> Locale:
+        try:
+            return Locale.from_any(self.locale)
+        except KeyError:
+            logger.warning(f"Locale '{self.locale}' not found. Defaulting to English.")
+            return Locale.English
 
     @classmethod
     def load(cls):
@@ -825,7 +869,7 @@ def load_config():
 
     if os.path.exists('config.json') and not os.path.exists(config_path):
         shutil.copy('config.json', config_path)
-
+        
     if os.path.exists(config_path):
         try:
             with open(config_path, 'r') as file:
@@ -840,20 +884,21 @@ def load_config():
                     config = ProfileConfig.from_dict(config_file)
                     new_config = Config(configs = {DEFAULT_CONFIG : config}, current_profile=DEFAULT_CONFIG)
 
-                    with open(config_path, 'w') as file:
-                        json.dump(new_config.to_dict(), file, indent=4)
+                    config.save()
                     return new_config
         except json.JSONDecodeError as e:
-            logger.error(f"Error parsing config.json: {e}")
-            return None
+            logger.error(f"Error parsing config.json, saving backup and returning new config: {e}")
+            shutil.copy(config_path, config_path + '.bak')
+            config = Config.new()
+            config.save()
+            return config
     elif os.path.exists('config.toml'):
         config = ProfileConfig().load_from_toml('config.toml')
         new_config = Config({DEFAULT_CONFIG: config}, current_profile=DEFAULT_CONFIG)
         return new_config
     else:
         config = Config.new()
-        with open(config_path, 'w') as file:
-            json.dump(config.to_dict(), file, indent=4)
+        config.save()
         return config
 
 
