@@ -168,8 +168,8 @@ def extract_text_with_pixel_boxes(
             
 
             for word in line.get("words", []):
-                if not regex.search(word.get("plain_text", "")):
-                    continue
+                # if not regex.search(word.get("plain_text", "")):
+                    # continue
                 word_text = word.get("plain_text", "")
                 line_text_parts.append(word_text)
                 
@@ -371,7 +371,7 @@ async def do_work(sentence_to_check=None):
         cropped_image.save("C:\\Users\\Beangate\\GSM\\temp\\full_screenshot.png")
     # full_screenshot_image.show()
     if cropped_image:
-        logger.info("Full screenshot captured successfully. Now performing local OCR...")
+        logger.info("Full screenshot captured successfully. Now performing OCR...")
         # ocr_results = oneocr(full_screenshot_image, return_coords=True)
         google_ocr_results = lens(cropped_image, return_coords=True)[2]
         
